

<img width = '200px' src = './logo.png'/>

### qsee: A quantum object search engine

**Contributors**: Vu Tuan Hai, Nguyen Tan Viet, Le Bin Ho

**Description**: Quantum programming is being used to address multiple problems in quantum technology fields, from quantum machine learning, quantum computing to quantum physics. Recent advances revolve around the use of quantum programming and quantum compiling, which promises to revolutionize program computation and boost quantum state preparation and tomography’s problem-solving capabilities. However, using quantum computing technologies requires high-level coding skills, which is not trivial for physics scientists. For such a reason, we propose qsee, a Python library that allows researchers and practitioners to configure and experiment with quantum compilation pipelines, within save and load results features for science reports. We showcase the architecture and main features of qsee, other than discussing its envisioned impact on research and practice.

**How to use**:

**Additional information**:

**Code of conducting**:

**License**: MIT LICENSE
